/*
 * input.h
 *
 *  Created on: 2021年12月4日
 *      Author: pengzc
 */

#ifndef JNI_INPUT_H_
#define JNI_INPUT_H_
#include <string>
#include <list>

#define CHECK_FAILURE(expression) \
  if ((expression) != 0) { \
    return -1; \
  }

#define ZKVTS_BASE          "/sys/class/zkvts"
#define ZKVTS_PACKAGE       "package"

#define ZKVTS_DEV           "/sys/class/zkvts/package"

enum VTS_ACTION_TYPE {
  VTS_ACTION_RELEASE = 0,//抬起
  VTS_ACTION_PRESSED = 1,//按下
};

struct zk_vts_point {
  int x; //坐标
  int y; //坐标
  VTS_ACTION_TYPE action;
};

struct Point {
  int x;
  int y;
};

/**
 * 基于系统接口，向系统注入触摸事件
 * 从而实现：模拟任何的触摸，不需要人为参与
 * 可以自定义触摸来源及协议，例如从串口接收指令，转为触摸事件，发送到系统中，从而实现界面控制
 */

class Input {
public:
  Input(const std::string& dev);
  virtual ~Input();

  //点击一系列的点
  int Tap(const std::list<Point>& points, int interval);
  //点击某个点
  int Tap(int x, int y);
  //从坐标(x1,y1) 滑动到 (x2,y2)
  int Swipe(int x1, int y1, int x2, int y2);

  //注入触摸事件
  int Inject(const zk_vts_point* point, int point_count);

  const static int kMoveDelayTime = 1;//ms
  const static int kPressureTime = 100;//ms

private:
  std::string dev_;
  int fd_;
};

#endif /* JNI_INPUT_H_ */
